@@ -13,7 +13,7 @@ use std::str::FromStr;
 #[cfg(test)]
 #[track_caller]
 fn assert_debug_equal<T: Debug>(a: T, b: T) {
-    assert_eq!(format!("{:?}", a), format!("{:?}", b),);
+    assert_eq!(format!("{a:?}"), format!("{b:?}"),);
 }
 
 #[cfg(test)]
@@ -108,6 +108,28 @@ fn test_parse_redis_socket() {
     );
 }
 
+#[test]
+fn test_parse_redis_db_str() {
+    let config = config_from_file("tests/configs/redis_db_str.php");
+    assert_debug_equal(
+        RedisConfig::Single(parse_redis("redis://127.0.0.1/1")),
+        config.redis,
+    );
+}
+
+#[test]
+fn test_parse_notify_push_redis() {
+    let config = config_from_file("tests/configs/notify_push_redis.php");
+    assert_debug_equal(
+        RedisConfig::Single(parse_redis("redis+unix:///redis1")),
+        config.redis,
+    );
+    assert_debug_equal(
+        Some(RedisConfig::Single(parse_redis("redis+unix:///redis2"))),
+        config.notify_push_redis,
+    );
+}
+
 #[test]
 fn test_parse_redis_tls() {
     let config = config_from_file("tests/configs/redis_tls.php");
@@ -340,7 +362,7 @@ fn test_parse_postgres_socket_folder() {
 fn test_parse_redis_cluster() {
     let config = config_from_file("tests/configs/redis.cluster.php");
     let mut addresses = config.redis.addr().cloned().collect::<Vec<_>>();
-    addresses.sort_by(|a, b| format!("{:?}", a).cmp(&format!("{:?}", b)));
+    addresses.sort();
     assert_debug_equal(
         vec![
             parse_redis("redis://:xxx@db1:6380").addr,
@@ -354,6 +376,14 @@ fn test_parse_redis_cluster() {
     );
 }
 
+#[test]
+fn test_parse_redis_cluster_single() {
+    let config = config_from_file("tests/configs/redis_cluster_single.php");
+    assert!(matches!(config.redis, RedisConfig::Cluster(_)));
+    let addresses = config.redis.addr().cloned().collect::<Vec<_>>();
+    assert_debug_equal(vec![parse_redis("redis://:xxx@db1:6380").addr], addresses);
+}
+
 #[test]
 fn test_parse_config_multiple() {
     let config = parse_glob("tests/configs/multiple/config.php").unwrap();
